@@ -12,6 +12,16 @@ require Exporter;
 
 @EXPORT = qw(assert create_suite run_suite add_suite);
 
+# NOTE: 
+# this version number has to be kept in sync 
+# with the number in the distribution file name 
+# (the distribution file is the tarball for CPAN release)
+# because the CPAN module decides to fetch the tarball by
+# looking at the version of this module if you say 
+# "install Test::Unit" in the CPAN shell
+
+$VERSION = '0.14';
+
 # private
 
 my $test_suite = Test::Unit::TestSuite->empty_new("Test::Unit");
@@ -100,7 +110,7 @@ __END__
 
 =head1 NAME
 
-    Test::Unit - Procedural style unit testing interface
+Test::Unit - Procedural style unit testing interface
 
 =head1 SYNOPSIS
 
@@ -129,62 +139,84 @@ __END__
 
 =head1 DESCRIPTION
 
-    Test::Unit is the procedural style interface to a sophisticated
-    unit testing framework for Perl that is derived from the JUnit
-    testing framework for Java by Kent Beck and Erich Gamma. While
-    this framework is originally intended to support unit testing
-    in an object-oriented development paradigm (with support for
-    inheritance of tests etc.), Test::Unit is intended to  provide
-    a simpler interface to the framework that is more suitable for
-    use in a scripting style environment. Therefore, Test::Unit
-    does not provide much support for an object-oriented approach
-    to unit testing - if you want that, please have a look at
-    Test::Unit::TestCase.
+Test::Unit is the procedural style interface to a sophisticated unit
+testing framework for Perl that is derived from the JUnit testing
+framework for Java by Kent Beck and Erich Gamma. While this framework
+is originally intended to support unit testing in an object-oriented
+development paradigm (with support for inheritance of tests etc.),
+Test::Unit is intended to provide a simpler interface to the framework
+that is more suitable for use in a scripting style environment.
+Therefore, Test::Unit does not provide much support for an
+object-oriented approach to unit testing - if you want that, please
+have a look at L<Test::Unit::TestCase>.
 
-    You test a given unit (a script, a module, whatever) by using
-    Test::Unit, which exports the following routines into your
-    namespace:
+You test a given unit (a script, a module, whatever) by using
+Test::Unit, which exports the following routines into your namespace:
 
-    assert()       - used to assert that a boolean condition is true
-    create_suite() - used to create a test suite consisting of all
-                     methods with a name prefix of 'test'
-    run_suite()    - runs the test suite (text output)
-    add_suite()    - used to add test suites to each other
-		     
-    For convenience, create_suite() will automatically build a test
-    suite for a given package. This will build a test case for each
-    subroutine in the package given that has a name starting with
-    "test" and pack them all together into one TestSuite object for
-    easy testing. If you dont give a package name to create_suite(),
-    the current package is taken as default.
+=over 4
 
-    Test output is one status line (a "." for every successful test
-    run, or an "F" for any failed test run, to indicate progress),
-    one result line ("OK" or "!!!FAILURES!!!"), and possibly many
-    lines reporting detailed error messages for any failed tests.
+=item assert()
 
-    Please remember, Test::Unit is intended to be a simple and
-    convenient interface. If you need more functionality, take the
-    object-oriented approach outlined in Test::Unit::TestCase.
+used to assert that a boolean condition is true
+
+=item create_suite()
+
+used to create a test suite consisting of all methods with a name
+prefix of C<test>
+
+=item run_suite()
+
+runs the test suite (text output)
+
+=item add_suite()
+
+used to add test suites to each other
+
+=back
+
+For convenience, C<create_suite()> will automatically build a test
+suite for a given package. This will build a test case for each
+subroutine in the package given that has a name starting with C<test>
+and pack them all together into one TestSuite object for easy testing.
+If you dont give a package name to C<create_suite()>, the current
+package is taken as default.
+
+Test output is one status line (a "." for every successful test run,
+or an "F" for any failed test run, to indicate progress), one result
+line ("OK" or "!!!FAILURES!!!"), and possibly many lines reporting
+detailed error messages for any failed tests.
+
+Please remember, Test::Unit is intended to be a simple and convenient
+interface. If you need more functionality, take the object-oriented
+approach outlined in L<Test::Unit::TestCase>.
 
 
 =head1 AUTHOR
 
-    Copyright (c) 2000, 2001 Christian Lemburg, <lemburg@acm.org>.
+Copyright (c) 2000, 2001 Christian Lemburg, E<lt>lemburg@acm.orgE<gt>.
 
-    All rights reserved. This program is free software; you can
-    redistribute it and/or modify it under the same terms as
-    Perl itself.
+All rights reserved. This program is free software; you can
+redistribute it and/or modify it under the same terms as Perl itself.
 
-    Thanks go to the other PerlUnit framework people: 
-    Brian Ewins, Cayte Lindner, J.E. Fritz, Zhon Johansen.
+Thanks go to the other PerlUnit framework people: 
+Brian Ewins, Cayte Lindner, J.E. Fritz, Zhon Johansen, Matthew Astley,
+Adam Spiers, Piers Cawley.
 
-    Thanks for patches go to:
-    Matthew Astley, David Esposito.
+Thanks for patches and other contributions go to:
+David Esposito, Kevin Connor.
 
 =head1 SEE ALSO
 
-    - Test::Unit::TestCase
-    - the procedural style examples in the examples directory
+=over 4
+
+=item *
+
+L<Test::Unit::TestCase>
+
+=item *
+
+the procedural style examples in the examples directory
+
+=back
 
 =cut
