@@ -1,20 +1,13 @@
 package Test::Unit::Assertion::Boolean;
-BEGIN {
-  $Test::Unit::Assertion::Boolean::VERSION = '0.25_1325'; # added by dist-tools/SetVersion.pl
-}
 
 use strict;
 
 # adding this fixes the 'Can't locate object method "fail" via package
 # "Test::Unit::Assertion::Boolean"' problem under perl 5.005 - Christian
 use Test::Unit::Assertion;
-use Test::Unit::Failure;
-
 
 use base 'Test::Unit::Assertion';
 
-use overload 'bool' => sub {$ {$_[0]}};
-
 sub new {
     my $class = shift;
     my $bool  = shift;
@@ -25,12 +18,7 @@ sub new {
 
 sub do_assertion {
     my $self = shift;
-    $$self or $self->fail( @_ ? join('', @_) : "Boolean assertion failed");
-}
-
-sub to_string {
-    my $self = shift;
-    ($$self ? 'TRUE' : 'FALSE') . ' boolean assertion';
+    $self->fail(@_) unless $$self;
 }
 
 1;
