@@ -1,10 +1,6 @@
 package Test::Unit::Assertion::Regexp;
-BEGIN {
-  $Test::Unit::Assertion::Regexp::VERSION = '0.25_1325'; # added by dist-tools/SetVersion.pl
-}
 
 use strict;
-use Test::Unit::Assertion;
 use base qw/Test::Unit::Assertion/;
 
 sub new {
@@ -17,13 +13,8 @@ sub new {
 sub do_assertion {
     my $self = shift;
     my $target = shift;
-    $target =~ $$self or
-        $self->fail(@_ ? $_[0] : "'$target' did not match /$$self/");
-}
-
-sub to_string {
-    my $self = shift;
-    "/$$self/ regexp assertion";
+    $target =~ $$self ||
+        $self->fail("'$target' did not match /$$self/");
 }
 
 1;
