@@ -3,11 +3,12 @@ use strict;
 use constant DEBUG => 0;
 
 sub new {
-    my $class = shift;
+    my $pkg = shift;
+    my $class = ref $pkg || $pkg;
     my ($message) = @_;
     
     $message = '' unless defined($message);
-    $message = ref($class) . ": " . $message . "\n";
+    $message = "$class:\n$message\n";
 
     my $i = 0;
     my $stacktrace = '';
@@ -47,36 +48,48 @@ __END__
 
 =head1 NAME
 
-    Test::Unit::Exception - unit testing framework exception class
+Test::Unit::Exception - unit testing framework exception class
 
 =head1 SYNOPSIS
 
-    # this class is not intended to be used directly 
+This class is not intended to be used directly 
 
 =head1 DESCRIPTION
 
-    This class is used by the framework to communicate the result
-    of assertions, which will throw an instance of a subclass
-    of this class in case of errors or failures.
+This class is used by the framework to communicate the result of
+assertions, which will throw an instance of a subclass of this class
+in case of errors or failures.
 
 =head1 AUTHOR
 
-    Copyright (c) 2000 Christian Lemburg, <lemburg@acm.org>.
+Copyright (c) 2000 Christian Lemburg, E<lt>lemburg@acm.orgE<gt>.
 
-    All rights reserved. This program is free software; you can
-    redistribute it and/or modify it under the same terms as
-    Perl itself.
+All rights reserved. This program is free software; you can
+redistribute it and/or modify it under the same terms as
+Perl itself.
 
-    Thanks go to the other PerlUnit framework people: 
-    Brian Ewins, Cayte Lindner, J.E. Fritz, Zhon Johansen.
+Thanks go to the other PerlUnit framework people: 
+Brian Ewins, Cayte Lindner, J.E. Fritz, Zhon Johansen.
 
-    Thanks for patches go to:
-    Matthew Astley.
+Thanks for patches go to:
+Matthew Astley.
 
 =head1 SEE ALSO
 
-    - Test::Unit::Assert
-    - Test::Unit::ExceptionError
-    - Test::Unit::ExceptionFailure
+=over 4
+
+=item *
+
+L<Test::Unit::Assert>
+
+=item *
+
+L<Test::Unit::ExceptionError>
+
+=item *
+
+L<Test::Unit::ExceptionFailure>
+
+=back
 
 =cut
