@@ -7,10 +7,6 @@ use Test::Unit::tests::TornDown;
 use Test::Unit::tests::WasRun;
 use Test::Unit::InnerClass;
 
-sub new {
-    shift()->SUPER::new(@_);
-}
-    
 sub verify_error {
     my $self = shift;
     my ($test) = @_;
@@ -18,6 +14,7 @@ sub verify_error {
     $self->assert($result->run_count() == 1);
     $self->assert($result->failure_count() == 0);
     $self->assert($result->error_count() == 1);
+    $self->assert(! $result->was_successful());
 }
 
 sub verify_failure {
@@ -27,6 +24,7 @@ sub verify_failure {
     $self->assert($result->run_count() == 1);
     $self->assert($result->failure_count() == 1);
     $self->assert($result->error_count() == 0);
+    $self->assert(! $result->was_successful());
 }
 
 sub verify_success {
@@ -36,12 +34,15 @@ sub verify_success {
     $self->assert($result->run_count() == 1);
     $self->assert($result->failure_count() == 0);
     $self->assert($result->error_count() == 0);
+    $self->assert($result->was_successful());
 }
 
 # test subs
 
 sub test_case_to_string {
     my $self = shift;
+    $self->assert(qr"test_case_to_string\(Test::Unit::tests::TestTest\)",
+                  $self->to_string);
     $self->assert($self->to_string() eq "test_case_to_string(Test::Unit::tests::TestTest)");
 }
 
@@ -179,11 +180,7 @@ sub run_test {
     $self->fail();
 }
 EOIC
-    my $result = $failure->run();
-    $self->assert($result->run_count() == 1);
-    $self->assert($result->failure_count() == 1);
-    $self->assert($result->error_count() == 0);
-    $self->assert(not $result->was_successful());
+    $self->verify_failure($failure);
 }
 
 sub test_was_run {
@@ -201,11 +198,7 @@ sub run_test {
     $self->assert(1);
 }
 EOIC
-    my $result = $success->run();
-    $self->assert($result->run_count() == 1);
-    $self->assert($result->failure_count() == 0);
-    $self->assert($result->error_count() == 0);
-    $self->assert($result->was_successful());
+    $self->verify_success($success);
 }
 
 sub test_assert_on_matching_regex {
@@ -214,13 +207,10 @@ sub test_assert_on_matching_regex {
 sub run_test {
     my $self = shift;
     $self->assert("foo" =~ /foo/, "Should have matched!");
+    $self->assert(qr/foo/, "foo");
 }
 EOIC
-    my $result = $matching_regex->run();
-    $self->assert($result->run_count() == 1);
-    $self->assert($result->failure_count() == 0);
-    $self->assert($result->error_count() == 0);
-    $self->assert($result->was_successful());
+    $self->verify_success($matching_regex);
 }
 
 sub test_assert_on_failing_regex {
@@ -229,13 +219,15 @@ sub test_assert_on_failing_regex {
 sub run_test {
     my $self = shift;
     $self->assert(scalar("foo" =~ /bar/), "Should not have matched!");
+    $self->assert(qr/bar/, "foo");
 }
 EOIC
-    my $result = $matching_regex->run();
-    $self->assert($result->run_count() == 1);
-    $self->assert($result->failure_count() == 1);
-    $self->assert($result->error_count() == 0);
-    $self->assert(not $result->was_successful());
+    $self->verify_failure($matching_regex);
 }
 
+sub test_assert_with_non_assertion_object {
+    my $self = shift;
+    my $obj = bless {}, 'NonExistentClass';
+    $self->assert($obj, "Object should eval to true");
+}
 1;
